@@ -2,11 +2,11 @@ import React, {PropTypes} from 'react';
 import FormLabel from '../../components/style/form-label'
 import FormColorInput from '../../components/style/form-color-input';
 
-export default function PropertyColor({propertyName, value, onUpdate, configs}) {
+export default function PropertyColor({value, onUpdate, configs}) {
   return (
     <div style={{marginBottom: "3px"}}>
       <div style={{display: "inline-block", width: "30%"}}>
-        <FormLabel>{propertyName}</FormLabel>
+        <FormLabel>{configs.label}</FormLabel>
       </div>
       <div style={{display: "inline-block", width: "70%"}}>
         <FormColorInput value={value} onChange={event => onUpdate(event.target.value)}/>
@@ -16,7 +16,6 @@ export default function PropertyColor({propertyName, value, onUpdate, configs})
 }
 
 PropertyColor.propTypes = {
-  propertyName: PropTypes.string.isRequired,
   value: PropTypes.any.isRequired,
   onUpdate: PropTypes.func.isRequired,
   configs: PropTypes.object.isRequired,
